@@ -6,7 +6,7 @@ EOL = b"\r\n"
 def _convert_bytes_to_dict(data: bytes) -> dict:
     respons = dict()
     list_values = list()
-    for _ in data.decode("utf-8").split(EOL.decode()):
+    for _ in data.decode("utf-8", errors='ignore').split(EOL.decode()):
         if _ != "":
             if _.split(": ", 1)[0] in respons.keys():
                 list_values.append(_.split(": ", 1)[1])
@@ -19,7 +19,7 @@ def _convert_bytes_to_dict(data: bytes) -> dict:
 def _convert_dict_to_bytes(data: dict) -> bytes:
     string = ""
     for _, __ in data.items():
-        if type(__) is list:
+        if isinstance(__, list):
             for value in __:
                 string += _ + ": " + value + EOL.decode()
         else:
